@@ -1,4 +1,4 @@
-#     Copyright 2017, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2019, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -23,62 +23,55 @@ import functools
 import sys
 from types import BuiltinFunctionType, FunctionType, GeneratorType
 
-from nuitka.__past__ import iterItems
+from nuitka.__past__ import builtins, iterItems
 from nuitka.PythonVersions import python_version
 
 
 def _getBuiltinExceptionNames():
     def isExceptionName(builtin_name):
-        if builtin_name.endswith("Error") or \
-           builtin_name.endswith("Exception"):
+        if builtin_name.endswith("Error") or builtin_name.endswith("Exception"):
             return True
-        elif builtin_name in ("StopIteration", "GeneratorExit", "SystemExit",
-                              "NotImplemented", "KeyboardInterrupt",
-                              "StopAsyncIteration"):
+        elif builtin_name in (
+            "StopIteration",
+            "GeneratorExit",
+            "SystemExit",
+            "NotImplemented",
+            "KeyboardInterrupt",
+            "StopAsyncIteration",
+        ):
             return True
         else:
             return False
 
+    exceptions = {}
+
     # Hide Python3 changes for built-in exception names
-    try:
-        import exceptions
+    if python_version < 300:
+        import exceptions as builtin_exceptions
 
-        names = [
-            str(name) for name in dir(exceptions)
-            if isExceptionName(name)
-        ]
-
-        values = {}
-
-        for key in names:
-            values[key] = getattr(exceptions, key)
-
-        for key in dir(sys.modules["__builtin__"]):
+        for key in dir(builtin_exceptions):
             name = str(key)
 
             if isExceptionName(name):
-                names.append(key)
-                values[name] = getattr(sys.modules["__builtin__"], key)
+                exceptions[name] = getattr(builtin_exceptions, key)
 
-    except ImportError:
-        exceptions = {}
+        for key in dir(builtins):
+            name = str(key)
 
-        for key, value in  sys.modules["builtins"].__dict__.items():
+            if isExceptionName(name):
+                exceptions[name] = getattr(builtins, key)
+    else:
+
+        for key in dir(builtins):
             if isExceptionName(key):
-                exceptions[key] = value
+                exceptions[key] = getattr(builtins, key)
 
-        names = [
-            key for key, value in exceptions.items()
-        ]
+    return list(exceptions.keys()), exceptions
 
-        values = {}
-
-        for key, value in exceptions.items():
-            values[key] = value
-
-    return names, values
 
 builtin_exception_names, builtin_exception_values = _getBuiltinExceptionNames()
+builtin_exception_values_list = tuple(builtin_exception_values.values())
+
 
 # Just to make sure it's covering these cases correctly.
 assert "TypeError" in builtin_exception_names
@@ -92,11 +85,9 @@ assert "NotImplemented" in builtin_exception_names
 
 assert "StopAsyncIteration" in builtin_exception_names or python_version < 350
 
+
 def _getBuiltinNames():
-    names = [
-        str(x)
-        for x in __builtins__.keys()
-    ]
+    names = [str(x) for x in dir(builtins)]
 
     for builtin_exception_name in builtin_exception_names:
         if builtin_exception_name in names:
@@ -109,6 +100,9 @@ def _getBuiltinNames():
     if "__loader__" in names:
         names.remove("__loader__")
 
+    if "__spec__" in names:
+        names.remove("__spec__")
+
     warnings = []
 
     for builtin_name in names:
@@ -120,7 +114,10 @@ def _getBuiltinNames():
 
     return names, warnings
 
+
 builtin_names, builtin_warnings = _getBuiltinNames()
+builtin_named_values = dict((getattr(builtins, x), x) for x in builtin_names)
+builtin_named_values_list = tuple(builtin_named_values)
 
 assert "__import__" in builtin_names
 assert "int" in builtin_names
@@ -130,11 +127,12 @@ assert "sys" not in builtin_names
 
 builtin_all_names = builtin_names + builtin_exception_names + builtin_warnings
 
+
 def getBuiltinTypeNames():
     result = []
 
     for builtin_name in builtin_names:
-        if isinstance(__builtins__[builtin_name], type):
+        if isinstance(getattr(builtins, builtin_name), type):
             result.append(builtin_name)
 
     return tuple(sorted(result))
@@ -147,29 +145,29 @@ def _getAnonBuiltins():
     with open(sys.executable) as any_file:
         anon_names = {
             # Strangely not Python3 types module
-            "NoneType"                   : type(None),
-            "ellipsis"                   : type(Ellipsis), # see above
-            "NotImplementedType"         : type(NotImplemented),
-            "function"                   : FunctionType,
-            "builtin_function_or_method" : BuiltinFunctionType,
+            "NoneType": type(None),
+            "ellipsis": type(Ellipsis),  # see above
+            "NotImplementedType": type(NotImplemented),
+            "function": FunctionType,
+            "builtin_function_or_method": BuiltinFunctionType,
             # Can't really have it any better way.
-            "compiled_function"          : BuiltinFunctionType,
-            "generator"                  : GeneratorType,
-            "compiled_generator"         : GeneratorType, # see above
-            "code"                       : type(_getAnonBuiltins.__code__),
-            "file"                       : type(any_file)
+            # "compiled_function"          : BuiltinFunctionType,
+            "generator": GeneratorType,
+            # "compiled_generator"         : GeneratorType, # see above
+            "code": type(_getAnonBuiltins.__code__),
+            "file": type(any_file),
         }
 
     anon_codes = {
-        "NoneType"                   : "Py_TYPE( Py_None )",
-        "ellipsis"                   : "&PyEllipsis_Type",
-        "NotImplementedType"         : "Py_TYPE( Py_NotImplemented )",
-        "function"                   : "&PyFunction_Type",
-        "builtin_function_or_method" : "&PyCFunction_Type",
-        "compiled_function"          : "&Nuitka_Function_Type",
-        "compiled_generator"         : "&Nuitka_Generator_Type",
-        "code"                       : "&PyCode_Type",
-        "file"                       : "&PyFile_Type"
+        "NoneType": "Py_TYPE( Py_None )",
+        "ellipsis": "&PyEllipsis_Type",
+        "NotImplementedType": "Py_TYPE( Py_NotImplemented )",
+        "function": "&PyFunction_Type",
+        "builtin_function_or_method": "&PyCFunction_Type",
+        "compiled_function": "&Nuitka_Function_Type",
+        "compiled_generator": "&Nuitka_Generator_Type",
+        "code": "&PyCode_Type",
+        "file": "&PyFile_Type",
     }
 
     if python_version < 300:
@@ -188,7 +186,14 @@ def _getAnonBuiltins():
 
     return anon_names, anon_codes
 
+
 builtin_anon_names, builtin_anon_codes = _getAnonBuiltins()
+builtin_anon_values = dict((b, a) for a, b in builtin_anon_names.items())
+
+# For being able to check if it's not hashable, we need something not using
+# a hash.
+builtin_anon_value_list = tuple(builtin_anon_values)
+
 
 def calledWithBuiltinArgumentNamesDecorator(f):
     """ Allow a function to be called with an "_arg" if a built-in name.
