@@ -1,4 +1,4 @@
-#     Copyright 2017, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2019, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Python tests originally created or extracted from other peoples work. The
 #     parts were too small to be protected.
@@ -15,5 +15,15 @@
 #     See the License for the specific language governing permissions and
 #     limitations under the License.
 #
+from __future__ import print_function
 
-print( "Imported PackageLocal", __name__, "in", __package__ )
+import sys
+
+print(
+    "Imported PackageLocal",
+    __name__,
+    "in",
+    __package__
+      if __package__ is not None or sys.version_info[:2] != (3,2) else
+    ".".join(__name__.split(".")[:-1])
+)
