@@ -1,4 +1,4 @@
-#     Copyright 2018, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2019, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Python test originally created or extracted from other peoples work. The
 #     parts from me are licensed as below. It is at least Free Software where
@@ -17,6 +17,7 @@
 #     See the License for the specific language governing permissions and
 #     limitations under the License.
 #
+from __future__ import print_function
 
 # Python3 changed module name.
 try:
@@ -24,4 +25,10 @@ try:
 except ImportError:
     import tkinter
 
-assert tkinter
+try:
+    root = tkinter.Tk()  # this will fail in absence of TCL
+except tkinter.TclError as e:
+    print("TCLError exception happened.")
+    assert "connect to display" in str(e) or "no display" in str(e), str(e)
+else:
+    print("OK")
